@@ -9,9 +9,7 @@
 #include <cstdarg>
 #include <list>
 #include <memory>
-#include <mutex>
 #include <string>
-#include <utility>
 #include <sys/types.h>
 #include <kopano/MAPIErrors.h>
 #include <kopano/memory.hpp>
