@@ -4,8 +4,9 @@
  */
 #pragma once
 #include <list>
-#include <vector>
 #include <memory>
+#include <string>
+#include <tuple>
 #include <mapidefs.h>
 #include <kopano/zcdefs.h>
 #include <kopano/ArchiveControl.h>
