@@ -5,9 +5,7 @@
 
 //////////////////////////////////////////////
 // Extended mapi definitions
-
-#ifndef ECMAPIEXT_H
-#define ECMAPIEXT_H
+#pragma once
 
 #ifndef MAPI_E_STORE_FULL
 #define MAPI_E_STORE_FULL (SCODE)0x8004060c
@@ -693,7 +691,7 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 /* from edkmapi.h .. or so they say on internet */
 /* Values of PR_NDR_REASON_CODE */
 #ifndef MAPI_REASON
-#define MAPI_REASON(_code)	((LONG) _code)
+#define MAPI_REASON(code) static_cast<int>(code)
 #define MAPI_REASON_TRANSFER_FAILED           MAPI_REASON( 0 )
 #define MAPI_REASON_TRANSFER_IMPOSSIBLE       MAPI_REASON( 1 )
 #define MAPI_REASON_CONVERSION_NOT_PERFORMED  MAPI_REASON( 2 )
@@ -792,5 +790,3 @@ PR_ADDITIONAL_REN_ENTRYIDS:
 
 #define PR_PROFILE_MDB_DN			PROP_TAG(PT_STRING8, 0x7CFF)
 #define PR_FORCE_USE_ENTRYID_SERVER PROP_TAG(PT_BOOLEAN, 0x7CFE)
-
-#endif
