@@ -2,14 +2,9 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-#ifndef PLATFORM_H
-#define PLATFORM_H
-
-  #ifdef HAVE_CONFIG_H
-  #include "config.h"
-  #endif
-  #include <kopano/platform.linux.h>
+#pragma once
 #include <kopano/zcdefs.h>
+#include <kopano/platform.linux.h>
 #include <mutex>
 #include <shared_mutex>
 #include <string>
@@ -28,6 +23,7 @@ namespace KC {
 
 #define S_IRWUG (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP)
 #define S_IRWXUG (S_IRWXU | S_IRWXG)
+#define S_IRWUGO (S_IRWUG | S_IROTH | S_IWOTH)
 
 #define KOPANO_SYSTEM_USER		"SYSTEM"
 #define KOPANO_SYSTEM_USER_W	L"SYSTEM"
@@ -35,14 +31,17 @@ namespace KC {
 /* This should match what is used in proto.h for __size */
 typedef int gsoap_size_t;
 
+extern KC_EXPORT const ULARGE_INTEGER ularge_int_zero;
+extern KC_EXPORT const LARGE_INTEGER large_int_zero;
+
 /*
  * Platform independent functions
  */
 // Random-number generators
-extern _kc_export void rand_init(void);
-extern _kc_export int rand_mt(void);
-extern _kc_export void rand_get(char *p, int n);
-extern _kc_export char *get_password(const char *prompt);
+extern KC_EXPORT void rand_init();
+extern KC_EXPORT int rand_mt();
+extern KC_EXPORT void rand_get(char *p, int n);
+extern KC_EXPORT char *get_password(const char *prompt);
 
 /**
  * Memory usage calculation macros
@@ -55,10 +54,10 @@ extern _kc_export char *get_password(const char *prompt);
 #define MEMORY_USAGE_STRING(str)			(str.capacity() + 1)
 #define MEMORY_USAGE_MULTIMAP(items, map)	MEMORY_USAGE_MAP(items, map)
 
-extern _kc_export void set_thread_name(pthread_t, const std::string &);
-extern _kc_export int ec_relocate_fd(int);
-extern _kc_export void kcsrv_blocksigs(void);
-extern _kc_export unsigned long kc_threadid(void);
+extern KC_EXPORT void set_thread_name(pthread_t, const std::string &);
+extern KC_EXPORT int ec_relocate_fd(int);
+extern KC_EXPORT void kcsrv_blocksigs();
+extern KC_EXPORT unsigned long kc_threadid();
 
 /* Determine the size of an array */
 template<typename T, size_t N> constexpr inline size_t ARRAY_SIZE(T (&)[N]) { return N; }
@@ -96,6 +95,13 @@ template<typename T> static inline constexpr const IID &iid_of(const T &)
 #	undef KC_BIGENDIAN
 #endif
 
+static inline uint16_t get_unaligned_le16(const uint16_t *p)
+{
+	uint16_t v;
+	memcpy(&v, p, sizeof(v));
+	return le16_to_cpu(v);
+}
+
 static inline uint32_t get_unaligned_le32(const uint32_t *p)
 {
 	uint32_t v;
@@ -103,7 +109,7 @@ static inline uint32_t get_unaligned_le32(const uint32_t *p)
 	return le32_to_cpu(v);
 }
 
-#if __cplusplus >= 201700L
+#ifdef KC_USES_CXX17
 using shared_mutex = std::shared_mutex;
 #else
 using shared_mutex = std::shared_timed_mutex;
@@ -119,5 +125,3 @@ typedef std::unique_lock<std::recursive_mutex> ulock_rec;
 
 #define IID_OF(T) namespace KC { template<> inline constexpr const IID &iid_of<T>() { return IID_ ## T; } }
 #define IID_OF2(T, U) namespace KC { template<> inline constexpr const IID &iid_of<T>() { return IID_ ## U; } }
-
-#endif // PLATFORM_H
