@@ -1,5 +1,5 @@
 #pragma once
-#include <stdexcept>
+#include <exception>
 #include <utility>
 
 namespace KC {
