@@ -2,14 +2,11 @@
  * SPDX-License-Identifier: AGPL-3.0-only
  * Copyright 2005 - 2016 Zarafa and its licensors
  */
-
 /*
  * edkmdb.h – Defines additional properties and interfaces offered by the
  * server-side information store.
  */
-
-#ifndef __M4L_EDKMDB_H_
-#define __M4L_EDKMDB_H_
+#pragma once
 
 /*
  * No, this is not the edkmdb.h file,
@@ -28,7 +25,7 @@
 #include <initializer_list>
 #include <edkguid.h>
 
-class IExchangeManageStore : public virtual IUnknown {
+struct IExchangeManageStore : public virtual IUnknown {
 public:
 	virtual HRESULT CreateStoreEntryID(const TCHAR *store_dn, const TCHAR *mbox_dn, ULONG flags, ULONG *eid_size, ENTRYID **eid) = 0;
 	virtual HRESULT EntryIDFromSourceKey(ULONG cFolderKeySize, BYTE *lpFolderSourceKey, ULONG cMessageKeySize, BYTE *lpMessageSourceKey, ULONG *lpcbEntryID, LPENTRYID *lppEntryID) = 0;
@@ -56,12 +53,10 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 #define pidLocalStoreInternalMin			0x6500
 #define pidLocalStoreInternalMax			0x65C0
 
-
 #define PR_NON_IPM_SUBTREE_ENTRYID			PROP_TAG( PT_BINARY, 0x6620)
 #define PR_IPM_FAVORITES_ENTRYID			PROP_TAG( PT_BINARY, 0x6630)
 #define PR_IPM_PUBLIC_FOLDERS_ENTRYID		PROP_TAG( PT_BINARY, 0x6631)
 
-
 /* missing PR_* defines for common/ECDebug */
 #define PR_PROFILE_VERSION					PROP_TAG(PT_LONG, 0x6600)
 #define PR_PROFILE_CONFIG_FLAGS				PROP_TAG(PT_LONG, 0x6601)
@@ -106,7 +101,6 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 
 #define PR_GET_PROPS_EXCLUDE_PROP_ID_LIST	PROP_TAG(PT_BINARY, 0x667E)
 
-
 #define PR_USER_ENTRYID						PROP_TAG(PT_BINARY, 0x6619)
 #define PR_USER_NAME						PROP_TAG( PT_TSTRING, 0x661A)
 #define PR_USER_NAME_A						PROP_TAG( PT_STRING8, 0x661A)
@@ -277,7 +271,6 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 #define PR_RECEIVED_BY_SID_AS_XML					PROP_TAG(PT_TSTRING, 0x0E77)
 #define PR_RCVD_REPRESENTING_SID_AS_XML				PROP_TAG(PT_TSTRING, 0x0E78)
 
-
 #define PR_MERGE_MIDSET_DELETED			PROP_TAG(PT_BINARY, 0x0E7A)
 #define PR_RESERVE_RANGE_OF_IDS			PROP_TAG(PT_BINARY, 0x0E7B)
 
@@ -441,7 +434,6 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 #define PR_QUOTA_SEND_THRESHOLD			PROP_TAG(PT_LONG, 0x6722)
 #define PR_QUOTA_RECEIVE_THRESHOLD		PROP_TAG(PT_LONG, 0x6723)
 
-
 #define PR_FOLDER_FLAGS							PROP_TAG(PT_LONG, 0x66A8)
 #define PR_LAST_ACCESS_TIME						PROP_TAG(PT_SYSTIME, 0x66A9)
 #define PR_RESTRICTION_COUNT					PROP_TAG(PT_LONG, 0x66AA)
@@ -572,8 +564,7 @@ typedef IExchangeManageStore* LPEXCHANGEMANAGESTORE;
 #define ROW_EMPTY			(ROW_ADD|ROW_REMOVE)
 
 struct ROWENTRY {
-	ULONG			ulRowFlags;
-	ULONG			cValues;
+	ULONG ulRowFlags, cValues;
 	LPSPropValue	rgPropVals;
 };
 typedef struct ROWENTRY *LPROWENTRY;
@@ -589,7 +580,7 @@ typedef struct ROWLIST *LPROWLIST;
 #define CbNewROWLIST(centries) \
 	(offsetof(ROWLIST, aEntries) + (centries) * sizeof(ROWENTRY))
 
-class IExchangeModifyTable : public virtual IUnknown {
+struct IExchangeModifyTable : public virtual IUnknown {
 public:
 	virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
 	virtual HRESULT GetTable(ULONG ulFlags, LPMAPITABLE *lppTable) = 0;
@@ -600,11 +591,9 @@ IID_OF(IExchangeModifyTable)
 typedef IExchangeModifyTable* LPEXCHANGEMODIFYTABLE;
 
 /* --- snip acl stuff --- */
-
 /*
  * Rules specifics
  */
-
 // Property types
 #define PT_SRESTRICTION				((ULONG) 0x00FD)
 #define PT_ACTIONS					((ULONG) 0x00FE)
@@ -619,7 +608,6 @@ typedef IExchangeModifyTable* LPEXCHANGEMODIFYTABLE;
  *					information to do conversion. This is internal to the store and
  *					is not supported for outside calls.
  */
-
 #define PT_FILE_HANDLE					((ULONG) 0x0103)
 #define PT_FILE_EA						((ULONG) 0x0104)
 #define PT_VIRTUAL						((ULONG) 0x0105)
@@ -707,20 +695,15 @@ enum ACTTYPE {
 //Action structure
 struct ACTION {
 	ACTTYPE		acttype;
-
 	// to indicate which flavor of the action.
 	ULONG		ulActionFlavor;
-
 	// Action restriction
 	// currently unused and must be set to NULL
 	LPSRestriction	lpRes;
-
 	// currently unused and must be set to NULL.
 	LPSPropTagArray lpPropTagArray;
-
 	// User defined flags
 	ULONG		ulFlags;
-
 	// padding to align the union on 8 byte boundary
 	ULONG		dwAlignPad;
 
@@ -748,10 +731,8 @@ struct ACTION {
 
 		// Error code to set for OP_BOUNCE action
 		SCODE			scBounceCode;
-
 		// list of address for OP_FORWARD and OP_DELEGATE action
 		LPADRLIST		lpadrlist;
-
 		// prop value for OP_TAG action
 		SPropValue		propTag;
 	};
@@ -811,8 +792,7 @@ HRESULT HrDeserializeActions(IMAPIProp * pprop, BYTE * pbActions, ULONG cbAction
  *
  * Used for get actions from a Deferred Action Message.
  */
-
-class IExchangeRuleAction : public virtual IUnknown {
+struct IExchangeRuleAction : public virtual IUnknown {
 public:
 	virtual HRESULT ActionCount(ULONG *lpcActions) = 0;
 	virtual HRESULT GetAction(ULONG ulActionNumber, LARGE_INTEGER *lpruleid, LPACTION *lppAction) = 0;
@@ -820,9 +800,8 @@ public:
 
 typedef IExchangeRuleAction* LPEXCHANGERULEACTION;
 
-
 //Outlook 2007, Blocked Attachments
-class IAttachmentSecurity : public virtual IUnknown {
+struct IAttachmentSecurity : public virtual IUnknown {
 public:
 	virtual HRESULT IsAttachmentBlocked(LPCWSTR pwszFileName, BOOL *pfBlocked) = 0;
 };
@@ -904,7 +883,7 @@ typedef struct READSTATE *LPREADSTATE;
 
 #define SYNC_READ					0x01
 
-class IExchangeExportChanges : public virtual IUnknown {
+struct IExchangeExportChanges : public virtual IUnknown {
 public:
 	virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
 	virtual HRESULT Config(LPSTREAM lpStream, ULONG ulFlags, LPUNKNOWN lpCollector, LPSRestriction lpRestriction, LPSPropTagArray lpIncludeProps, LPSPropTagArray lpExcludeProps, ULONG ulBufferSize) = 0;
@@ -914,7 +893,7 @@ public:
 
 typedef IExchangeExportChanges* LPEXCHANGEEXPORTCHANGES;
 
-class IExchangeImportContentsChanges : public virtual IUnknown {
+struct IExchangeImportContentsChanges : public virtual IUnknown {
 public:
 	virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
 	virtual HRESULT Config(LPSTREAM lpStream, ULONG ulFlags) = 0;
@@ -927,7 +906,7 @@ public:
 
 typedef IExchangeImportContentsChanges* LPEXCHANGEIMPORTCONTENTSCHANGES;
 
-class IExchangeImportHierarchyChanges : public virtual IUnknown {
+struct IExchangeImportHierarchyChanges : public virtual IUnknown {
 public:
 	virtual HRESULT GetLastError(HRESULT hResult, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
 	virtual HRESULT Config(LPSTREAM lpStream, ULONG ulFlags) = 0;
@@ -938,7 +917,7 @@ public:
 
 typedef IExchangeImportHierarchyChanges* LPEXCHANGEIMPORTHIERARCHYCHANGES;
 
-class IProxyStoreObject : public virtual IUnknown {
+struct IProxyStoreObject : public virtual IUnknown {
 public:
 	virtual HRESULT UnwrapNoRef(LPVOID *ppvObject) = 0;
 };
@@ -950,14 +929,14 @@ typedef IProxyStoreObject* LPPROXYSTOREOBJECT;
 
 // Outlook 2007
 // Provides information about a folder's support for sharing.
-class IFolderSupport : public virtual IUnknown {
+struct IFolderSupport : public virtual IUnknown {
 public:
 	virtual HRESULT GetSupportMask(DWORD *pdwSupportMask) = 0;
 };
 
 typedef IFolderSupport* LPIFOLDERSUPPORT;
 
-class IExchangeFavorites : public virtual IUnknown {
+struct IExchangeFavorites : public virtual IUnknown {
 public:
 	virtual HRESULT GetLastError(HRESULT hr, ULONG ulFlags, LPMAPIERROR *lppMAPIError) = 0;
 	virtual HRESULT AddFavorites(LPENTRYLIST lpEntryList) = 0;
@@ -965,12 +944,9 @@ public:
 };
 
 /* New from Outlook 2010 MAPI Extension */
-class IMAPIGetSession : public virtual IUnknown {
+struct IMAPIGetSession : public virtual IUnknown {
 public:
 	virtual HRESULT GetMAPISession(LPUNKNOWN *lppSession) = 0;
 };
 
 typedef IMAPIGetSession* LPMAPIGETSESSION;
-
-
-#endif
