@@ -67,7 +67,7 @@ from .errors import NotFoundError, ArgumentError, DuplicateError
 from .query import _query_to_restriction
 
 from .compat import (
-    fake_unicode as _unicode, bdec as _bdec, benc as _benc
+    bdec as _bdec, benc as _benc
 )
 
 try:
@@ -268,7 +268,7 @@ class Folder(Properties):
 
     @name.setter
     def name(self, name):
-        self.mapiobj.SetProps([SPropValue(PR_DISPLAY_NAME_W, _unicode(name))])
+        self.mapiobj.SetProps([SPropValue(PR_DISPLAY_NAME_W, str(name))])
         _utils._save(self.mapiobj)
 
     @property
@@ -294,7 +294,7 @@ class Folder(Properties):
     def container_class(self, value):
         if value is None:
             return
-        prop = SPropValue(PR_CONTAINER_CLASS_W, _unicode(value))
+        prop = SPropValue(PR_CONTAINER_CLASS_W, str(value))
         self.mapiobj.SetProps([prop])
         _utils._save(self.mapiobj)
 
@@ -334,7 +334,7 @@ class Folder(Properties):
             table = self.mapiobj.GetContentsTable(MAPI_DEFERRED_ERRORS)
             table.SetColumns([PR_ENTRYID, PR_SOURCE_KEY], 0)
             table.Restrict(restriction, 0)
-            rows = list(table.QueryRows(-1, 0))
+            rows = list(table.QueryRows(2147483647, 0))
             if not rows:
                 raise NotFoundError("no item with sourcekey '%s'" % sourcekey)
             eid = rows[0][0].Value
@@ -440,7 +440,7 @@ class Folder(Properties):
             # TODO use shortcuts and default type (database) to avoid
             # MAPI snake wrestling
             NAMED_PROPS = [MAPINAMEID(PSETID_Appointment, MNID_ID, x)
-                for x in (33285, 33293, 33294, 33315, 33301, 33333, 33334)]
+                for x in (33285, 33293, 33294, 33315, 33301, 33333, 33334, 33331, 33302)]
             ids = self.mapiobj.GetIDsFromNames(NAMED_PROPS, MAPI_CREATE)
             busystatus = ids[0] | PT_LONG
             startdate = ids[1] | PT_SYSTIME
@@ -449,6 +449,8 @@ class Folder(Properties):
             all_day = ids[4] | PT_BOOLEAN
             clip_start = ids[5] | PT_SYSTIME
             clip_end = ids[6] | PT_SYSTIME
+            tzinfo = ids[7] | PT_BINARY
+            blob = ids[8] | PT_BINARY
 
             restriction = SOrRestriction([
                 # non-recurring: normal start/end
@@ -494,7 +496,9 @@ class Folder(Properties):
                 enddate,
                 recurring,
                 all_day,
-                busystatus
+                busystatus,
+                tzinfo,
+                blob, # watch out: can be larger than 255 chars.
             ]
 
             table = Table(
@@ -725,7 +729,7 @@ class Folder(Properties):
             name = path.replace('\\/', '/')
             try:
                 mapifolder = self.mapiobj.CreateFolder(FOLDER_GENERIC,
-                    _unicode(name), '', None, MAPI_UNICODE)
+                    str(name), '', None, MAPI_UNICODE)
                 return Folder(self.store, _benc(HrGetOneProp(mapifolder,
                     PR_ENTRYID).Value))
             except MAPIErrorCollision:
@@ -733,7 +737,7 @@ class Folder(Properties):
 
         name = path.replace('\\/', '/')
         restriction = Restriction(SPropertyRestriction(RELOP_EQ,
-            PR_DISPLAY_NAME_W, SPropValue(PR_DISPLAY_NAME_W, _unicode(name))))
+            PR_DISPLAY_NAME_W, SPropValue(PR_DISPLAY_NAME_W, str(name))))
 
         folders = list(self.folders(recurse=recurse, restriction=restriction))
         if not folders:
@@ -863,7 +867,7 @@ class Folder(Properties):
         :param restriction: Rule :class:`restriction <Restriction>` (optional)
         """
         if name:
-            name = _unicode(name)
+            name = str(name)
 
         propid = len(list(self.rules()))+1
         row = [
@@ -938,29 +942,33 @@ class Folder(Properties):
             except (MAPIErrorNotFound, NotFoundError):
                 pass
             else:
-                etxml = ElementTree.fromstring(ruledata)
+                try:
+                    etxml = ElementTree.fromstring(ruledata)
+                except ElementTree.ParseError as e:
+                    log.warning("ElementTree.fromstring(ruledata): folder %s: %s", self.name, str(e))
+                    return None
                 for actions in etxml.findall('./item/item/actions'):
                     for movecopy in actions.findall('.//moveCopy'):
                         try:
                             s = movecopy.findall('store')[0]
-                            store = server.mapisession.OpenMsgStore(0,
-                                _unbase64(s.text), None, 0)
-                            entryid = \
-                                HrGetOneProp(store, PR_STORE_ENTRYID).Value
+                            store = server.mapisession.OpenMsgStore(0, _unbase64(s.text), None, 0)
+                            entryid = HrGetOneProp(store, PR_STORE_ENTRYID).Value
                             store = server.store(entryid=_benc(entryid))
                             if store.public:
                                 s.text = 'public'
                             else:
-                                s.text = store.user.name \
-                                    if store != self.store else ''
+                                s.text = store.user.name if store != self.store else ''
                             f = movecopy.findall('folder')[0]
                             path = store.folder(
                                 entryid=_benc(_unbase64(f.text))).path
                             f.text = path
                         except Exception as e:
-                            log.warning(
-                                "could not resolve rule target: %s", str(e))
-                ruledata = ElementTree.tostring(etxml)
+                            log.warning("could not resolve rule target: %s", str(e))
+                try:
+                    ruledata = ElementTree.tostring(etxml)
+                except ElementTree.ParseError as e:
+                    log.warning("Unable to backup rules for folder %s : %s", self.name,  str(e))
+                    return None
 
         return _utils.pickle_dumps({
             b'data': ruledata
@@ -1098,7 +1106,7 @@ class Folder(Properties):
         :param ics: the iCal data
         """
         icm = icalmapi.CreateICalToMapi(self.mapiobj, self.server.ab, False)
-        icm.ParseICal(ics, 'utf-8', '', None, 0)
+        icm.ParseICal(ics, 'utf-8', 'UTC', self.store.user.mapiobj, 0)
         for i in range(0, icm.GetItemCount()):
             mapiobj = self.mapiobj.CreateMessage(None, 0)
             icm.GetItem(i, 0, mapiobj)
@@ -1176,16 +1184,16 @@ class Folder(Properties):
         restriction = SOrRestriction([
             SContentRestriction(FL_SUBSTRING | FL_IGNORECASE,
                 PR_SUBJECT_W,
-                SPropValue(PR_SUBJECT_W, _unicode(text))),
+                SPropValue(PR_SUBJECT_W, str(text))),
             SContentRestriction(FL_SUBSTRING | FL_IGNORECASE,
                 PR_BODY_W,
-                SPropValue(PR_BODY_W, _unicode(text))),
+                SPropValue(PR_BODY_W, str(text))),
             SContentRestriction(FL_SUBSTRING | FL_IGNORECASE,
                 PR_DISPLAY_TO_W,
-                SPropValue(PR_DISPLAY_TO_W, _unicode(text))),
+                SPropValue(PR_DISPLAY_TO_W, str(text))),
             SContentRestriction(FL_SUBSTRING | FL_IGNORECASE,
                 PR_DISPLAY_NAME_W,
-                SPropValue(PR_DISPLAY_NAME_W, _unicode(text))),
+                SPropValue(PR_DISPLAY_NAME_W, str(text))),
             # TODO add all default fields..
             # BUT perform full-text search by default!
         ])
