@@ -54,13 +54,11 @@ def _daemon_helper(func, service, log):
             service.log_queue.close()
             service.log_queue.join_thread()
 
-def _daemonize(func, options=None, foreground=False, log=None, config=None,
+def _daemonize(func, options=None, log=None, config=None,
         service=None):
     uid = gid = None
-    working_directory = '/'
     pidfile = None
     if config:
-        working_directory = config.get('running_path')
         pidfile = config.get('pid_file')
         if config.get('run_as_user'):
             uid = pwd.getpwnam(config.get('run_as_user')).pw_uid
@@ -87,19 +85,16 @@ def _daemonize(func, options=None, foreground=False, log=None, config=None,
         for h in log.handlers:
             if isinstance(h, logging.handlers.WatchedFileHandler):
                 os.chown(h.baseFilename, uid, gid)
-    if options and options.foreground:
-        foreground = options.foreground
-        working_directory = os.getcwd()
     with daemon.DaemonContext(
             pidfile=pidfile,
             uid=uid,
             gid=gid,
-            working_directory=working_directory,
+            working_directory='/',
             files_preserve=[h.stream for h in log.handlers if \
                 isinstance(h, logging.handlers.WatchedFileHandler)] \
                     if log else None,
             prevent_core=False,
-            detach_process=not foreground,
+            detach_process=False,
             stdout=sys.stdout,
             stderr=sys.stderr,
     ):
@@ -138,8 +133,6 @@ Encapsulates everything to create a simple Kopano service, such as:
             # TODO useful during testing.
             # could be generalized with optparse callback?
             options.config_file = os.path.abspath(options.config_file)
-        if not getattr(options, 'service', True):
-            options.foreground = True
         #: Service :class:`configuration <Config>` instance.
         self.config = _config.Config(config2, service=name, options=options)
         self.config.data['server_socket'] = \
@@ -183,7 +176,7 @@ Encapsulates everything to create a simple Kopano service, such as:
 
         self.log.info('starting %s', self.logname or self.name)
         try:
-            # do not run-as-service (eg backup)
+            # do not run-as-service (e.g. backup)
             if getattr(self.options, 'service', True):
                 _daemonize(self.main, options=self.options, log=self.log,
                     config=self.config, service=self)
